@@ -42,7 +42,7 @@ Matijs van Zuijlen, C<matijs@matijs.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002, 2004, 2006, 2007 by Matijs van Zuijlen
+Copyright 2002, 2004, 2006--2008 by Matijs van Zuijlen
 
 This module is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
@@ -55,13 +55,14 @@ use Email::MIME::Creator;
 use Email::MIME::ContentType;
 use OLE::Storage_Lite;
 use POSIX;
+use Encode;
 use Carp;
 
 my $DIR_TYPE = 1;
 my $FILE_TYPE = 2;
 
 use vars qw($VERSION);
-$VERSION = "0.904";
+$VERSION = "0.905";
 #
 # Descriptions partially based on mapitags.h
 #
@@ -208,7 +209,7 @@ sub new {
 
   my $msg = OLE::Storage_Lite->new($file);
   my $pps = $msg->getPpsTree(1);
-  $pps or croak "Parsing $file as OLE file failed.";
+  $pps or croak "Parsing $file as OLE file failed";
   $self->_set_verbosity($verbose);
   $self->_process_root_dir($pps);
 
@@ -430,8 +431,10 @@ sub _process_pps_file_entry {
 
   if (defined $property and my $arr = $map->{$property}) {
     my $data = $pps->{Data};
-    # FIXME: This probably messes up unicode processing.
     if ($arr->[1]) {
+      if ($encoding eq $ENCODING_UNICODE) {
+	$data = decode("UTF-16LE", $data);
+      }
       $data =~ s/\000$//sg;
       $data =~ s/\r\n/\n/sg;
     }
@@ -559,8 +562,6 @@ sub _parse_item_name {
   if ($name =~ /^__substg1 0_(....)(....)$/) {
     my ($property, $encoding) = ($1, $2);
     if ($encoding eq $ENCODING_UNICODE and not ($self->{HAS_UNICODE})) {
-      warn "This msg file contains Unicode fields."
-	. " This is currently unsupported.\n";
       $self->{HAS_UNICODE} = 1;
     } elsif (not $KNOWN_ENCODINGS->{$encoding}) {
       warn "Unknown encoding $encoding. Results may be strange or wrong.\n";
